![madcad-logo](uimadcad/icons/madcad.png)

# UI-MADCAD

User-friendly graphical environment for madcad 

- [Official website](https://madcad.netlify.app)
- [Repository](https://github.com/jimy-byerley/pymadcad)
- [Matrix community](https://matrix.to/#/#madcad:matrix.org)

[![support-version](https://img.shields.io/pypi/pyversions/uimadcad.svg)](https://img.shields.io/pypi/pyversions/pymadcad)
[![PyPI version shields.io](https://img.shields.io/pypi/v/uimadcad.svg)](https://pypi.org/project/pymadcad/)
[![Documentation Status](https://readthedocs.org/projects/pymadcad/badge/?version=latest)](https://pymadcad.readthedocs.io/en/latest/?badge=latest)
[![#madcad:matrix.org](https://img.shields.io/matrix/madcad:matrix.org.svg)](https://matrix.to/#/#madcad:matrix.org)

![uimadcad interface](screenshots/interface-green.png)

## Features

- 3d geometry interactive edition
- partial execution of code (only the modified code is re-executed)
- quick tools to easily generate 3d primitive objects
- multi-view 3d scene
- multi-view script editor
- fast scene composition for each view
- themable GUI

## About

While **pymadcad** is a powerful and intuitive python module, any  code generating a 3d model still is a script full of coordinates and  computational instructions, that one needs to reexecute and wait for its result to show and every time you change a value. **uimadcad** allows you to view every variable, every expression  in your code just by clicking on it, and interact with the display to  edit it.
With **uimadcad**, you still work on the script, but you can combine the best of both world (text & graphic) together to model faster.

This software is a bit like [openscad](https://openscad.org/) but  using python rather than a dedicated language. I discovered openscad after started developing uimadcad.

## License   ![LGPL logo](https://www.gnu.org/graphics/gplv3-88x31.png)

Copyright 2019-2023 Yves Dejonghe <jimy.byerley@gmail.com>

This software is distributed under GPL-v3 license. A copy of that license is provided with this software.